@@ -2,9 +2,9 @@ from dataclasses import dataclass
 from math import ceil
 from typing import Tuple
 
+from . import constants
 from .candle import Candle, CandleType
 from .colors import truecolor
-from .constants import UNICODE_FILL, UNICODE_HALF_BODY_BOTTOM
 
 
 @dataclass(slots=True)
@@ -13,7 +13,7 @@ class VolumePane:
     enabled: bool = True
     bearish_color: Tuple[int, int, int] = (234, 74, 90)
     bullish_color: Tuple[int, int, int] = (52, 208, 88)
-    unicode_fill: str = UNICODE_FILL
+    unicode_fill: str = constants.UNICODE_FILL
 
     def _colorize(self, candle_type: int, string: str) -> str:
         color = (
@@ -30,7 +30,7 @@ class VolumePane:
         if y < ceil(ratio):
             return self._colorize(candle.type, self.unicode_fill)
 
-        if y == 1 and self.unicode_fill == UNICODE_FILL:
-            return self._colorize(candle.type, UNICODE_HALF_BODY_BOTTOM)
+        if y == 1 and self.unicode_fill == constants.UNICODE_FILL:
+            return self._colorize(candle.type, constants.UNICODE_HALF_BODY_BOTTOM)
 
         return " "
